from fastapi_jsonrpc import BaseError


class CryptoServiceError(BaseError):
    CODE = -5000
    MESSAGE = "Error occured running CryptoService."


class FailedToCreateHashError(BaseError):
    CODE = -5100
    MESSAGE = "Failed to create hash for given instance."


class HashNotMatchError(BaseError):
    CODE = -5200
    MESSAGE = "Hashes do not match."



import os
from jsonrpcclient.responses import Response
from ports_v2_core.rpc.errors import (
    AuthenticationError,
    AuthorizationError,
    MfaVerificationError,
)

from ports_v2_core.rpc.clients import BaseRpcClient
from ports_v2_core.schemas import (
    MfaVerifySchema,
    SecretsSchema,
    SessionSecretsSchema,
    UserLoginSchema,
)


class AuthRpcService(BaseRpcClient):
    url: str = os.environ.get("AUTH_RPC_URL")
    LOGIN_USER = "login_user"
    VERIFY_LOGIN = "verify_login"
    VERIFY_AUTHENTICATION = "verify_authentication"

    @classmethod
    def login_user(cls, data: UserLoginSchema) -> SecretsSchema:
        params = data.dict()
        response: Response = cls.send_request(cls, cls.LOGIN_USER, params)
        if hasattr(response, "message"):
            raise AuthorizationError()
        secrets = SecretsSchema(**response.result)
        return secrets

    @classmethod
    def login_verify(cls, data: MfaVerifySchema) -> SecretsSchema:
        params = data.dict()
        response: Response = cls.send_request(cls, cls.VERIFY_LOGIN, params)
        if hasattr(response, "message"):
            raise MfaVerificationError()
        secrets = SecretsSchema(**response.result)
        return secrets

    @classmethod
    def verify_authentication(cls, data: SessionSecretsSchema) -> SecretsSchema:
        params = data.dict()
        response: Response = cls.send_request(cls, cls.VERIFY_AUTHENTICATION, params)
        if hasattr(response, "message"):
            raise AuthenticationError()
        secrets = SecretsSchema(**response.result)
        return secrets



import os
import logging
from jsonrpcclient.responses import Response
from ports_v2_core.rpc.errors import FailedCreateUserError, UserNotFoundError

from ports_v2_core.rpc.clients import BaseRpcClient
from ports_v2_core.schemas import CreateUserSchema, UserSchema

logger = logging.getLogger(__name__)


class UserRpcClient(BaseRpcClient):
    url: str = os.environ.get("USER_RPC_URL")
    GET_BY_EMAIL = "get_user_by_email"
    GET_BY_ID = "get_user_by_id"
    CREATE_USER = "create_user"

    @classmethod
    def get_user_by_email(cls, email: str) -> UserSchema:
        params = {"email": email}
        response: Response = cls.send_request(cls, cls.GET_BY_EMAIL, params)
        if hasattr(response, "message"):
            raise UserNotFoundError()
        user = UserSchema(**response.result)
        return user

    @classmethod
    def get_user_by_id(cls, user_id: str) -> UserSchema:
        params = {"user_id": user_id}
        response: Response = cls.send_request(cls, cls.GET_BY_ID, params)

        if hasattr(response, "message"):
            raise UserNotFoundError()
        user = UserSchema(**response.result)
        return user

    @classmethod
    def create_new_user(cls, data: CreateUserSchema) -> UserSchema:
        params = data.dict()
        response: Response = cls.send_request(cls, cls.CREATE_USER, params)
        if hasattr(response, "message"):
            raise FailedCreateUserError()
        return UserSchema(**response.result)



from ports_v2_core.rpc.errors.users import UserNotFoundError, FailedCreateUserError
from ports_v2_core.rpc.errors.crypto import (
    CryptoServiceError,
    FailedToCreateHashError,
    HashNotMatchError,
)
from ports_v2_core.rpc.errors.auth import (
    AuthorizationError,
    MfaVerificationError,
    AuthenticationError,
)



import logging
import requests
from typing import Union
from requests.exceptions import MissingSchema, ConnectionError
from jsonrpcclient import request, parse
from fastapi_jsonrpc import BaseError, BaseModel
from dotenv import load_dotenv

load_dotenv()


logger = logging.getLogger(__name__)


class RpcClientError(BaseError):
    CODE = -1111
    MESSAGE = "Service error."

    class DataModel(BaseModel):
        details: Union[str, dict]


# It sends a request to the service and parses the response
class BaseRpcClient:
    url: str

    def send_request(self, method, params):
        """
        It sends a request to the server, and if it fails, it logs the error and raises a ServiceError

        :param method: The method to call on the service
        :param params: a dictionary of parameters to be sent to the service
        """
        try:
            response = requests.post(self.url, json=request(method, params))
        except (MissingSchema, ConnectionError) as e:
            logger.error(e)
            raise RpcClientError(data={"details": str(e)})
        try:
            return parse(response.json())
        except (TypeError, KeyError):
            logger.error(response.json())
            raise RpcClientError(data={"details": response.json()})



from fastapi_jsonrpc import BaseError


class AuthorizationError(BaseError):
    CODE = -4000
    MESSAGE = "Failed to authorize with given credentials."


class MfaVerificationError(BaseError):
    CODE = -4100
    MESSAGE = "Cannot verify given mfa credentials."


class AuthenticationError(BaseError):
    CODE = -4200
    MESSAGE = "Authentication failed for given secrets."



from fastapi_jsonrpc import BaseError


class FailedCreateUserError(BaseError):
    CODE = -3000
    MESSAGE = "Failed to create user."


class UserNotFoundError(BaseError):
    """
    Error that show that user was not found inside the UserService
    with the given credentials.
    """

    CODE = -3100
    MESSAGE = "No user was found with given credentials."



import os
import logging
from jsonrpcclient.responses import Response

from ports_v2_core.rpc.clients import BaseRpcClient
from ports_v2_core.rpc.errors import (
    CryptoServiceError,
    FailedToCreateHashError,
    HashNotMatchError,
)


logger = logging.getLogger(__name__)


class CryptoRpcClien(BaseRpcClient):
    url: str = os.environ.get("CRYPTO_RPC_URL")
    COMPARE_HASH = "compare_hash"
    CREATE_HASH = "create_hash"

    @classmethod
    def compare_hash(cls, plain_text: str, hashed: str) -> dict:
        """
        It compares the hash of the plain text with the hash provided.
        :param cls: The class that is calling the method
        :param plain_text: The plain text to be hashed
        :type plain_text: str
        :param hashed: The hash value to be compared
        :type hashed: str
        """
        params = {
            "plain_text": plain_text,
            "hashed": hashed,
        }
        response: Response = cls.send_request(cls, cls.COMPARE_HASH, params)
        if hasattr(response, "message"):
            logger.error(response.message)
            raise CryptoServiceError()
        if not response.result:
            raise HashNotMatchError()

    @classmethod
    def create_hash(cls, data: str):
        """
        It takes a string as input, and returns a hash of that string
        :param cls: The class that is calling the method
        :param data: The data to be hashed
        :type data: str
        :return: The hash of the data
        """
        params = {"data": data}
        response: Response = cls.send_request(cls, cls.CREATE_HASH, params)
        if hasattr(response, "message"):
            logger.error(response.message)
            raise FailedToCreateHashError()
        return response.result



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['ports_v2_core',
 'ports_v2_core.rpc',
 'ports_v2_core.rpc.clients',
 'ports_v2_core.rpc.errors',
 'ports_v2_core.schemas']

package_data = \
{'': ['*']}

install_requires = \
['fastapi-jsonrpc>=2.2.2,<3.0.0',
 'jsonrpcclient>=4.0.2,<5.0.0',
 'pydantic[email]>=1.9.1,<2.0.0',
 'python-dotenv>=0.20.0,<0.21.0',
 'requests>=2.28.1,<3.0.0']

setup_kwargs = {
    'name': 'ports-v2-core',
    'version': '0.1.6',
    'description': '',
    'long_description': None,
    'author': 'Your Name',
    'author_email': 'you@example.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)



from datetime import datetime
from enum import Enum
from pydantic import BaseModel, EmailStr
from uuid import UUID


class EUserStatus(Enum):
    ACTIVE = "ACTIVE"
    PENDING = "PENDING"
    BLOCKED = "BLOCKED"


class UserSchema(BaseModel):
    """
    User pydantic schema.
    Represent user retrieved from UserService
    """

    id: UUID
    email: EmailStr
    name: str
    hashed_password: str
    mfa_enabled: bool = False
    status: EUserStatus
    created_at: datetime
    updated_at: datetime


class CreateUserSchema(BaseModel):
    email: EmailStr
    name: str
    password: str
    mfa_enabled: bool = False


class UserLoginSchema(BaseModel):
    email: EmailStr
    password: str


class SecretsSchema(BaseModel):
    id: str
    secret: str


class MfaVerifySchema(BaseModel):
    record_uuid: str
    mfa_code: str


class SessionSecretsSchema(BaseModel):
    session_id: str
    secret: str
